unit Unit1;

interface

type
  ShortName = string[32];
  TEmployee = class(TPersistent)
  private
    FLock: integer;
    FFirstName: ShortName;
    FLastName: ShortName;
    FParentList: TList;
    FLastWork: string;
    procedure SetFirstName(const Value: ShortName);
    procedure SetLastName(const Value: ShortName);
    procedure SetLastWork(const Value: string);
    function GetLock: Boolean;
  public
    constructor Create; override;
    destructor Destroy; override;
    procedure Lock;
    procedure Unlock;
    property Locked: Boolean read GetLock;
  published
    property FirstName: ShortName read FFirstName write SetFirstName;
    property LastName: ShortName read FLastName write SetLastName;
    property LastWork: string read FLastWork write SetLastWork;
    property ParentList: TList read FParentList;
  end;

var
  RootEmployee: TEmployee = nil;

function CompareStr(const S1,S2: string): Boolean;

implementation

const
  UnknownWork = 'N/A';
  
{ TEmployee }

constructor TEmployee.Create;
begin
  FLock:=0;
  FFirstName:='';
  FLastName:='';
  FParentList:=TList.Create;
  FLastWork:=UnknownWork;
end;

destructor TEmployee.Destroy;
begin
  FParentList.Free;
end;

function TEmployee.GetLock: Boolean;
begin
  Result:=FLock > 0;
end;

procedure TEmployee.Lock;
begin
  Inc(FLock);
end;

procedure TEmployee.SetFirstName(const Value: ShortName);
begin
  FFirstName := Value;
end;

procedure TEmployee.SetLastName(const Value: ShortName);
begin
  if FLastName <> Value then
    FLastName := Value;
end;

procedure TEmployee.SetLastWork(const Value: string);
begin
  FLastWork := Value;
end;

procedure TEmployee.Unlock;
begin
  Dec(FLock);
end;

function CompareStr(const S1,S2: string): Boolean;
begin
  Result := AnsiCompareText(S1,S2) = 0;
end;

initialization
finalization
  if RootEmployee <> nil then
    RootEmployee.Free;
end.
